[![Build Status](https://travis-ci.org/wiki-ai/ores.svg)](https://travis-ci.org/wiki-ai/ores)

Objective Revision Evaluation Service
=====================================
A webserver for hosting scoring services. For more information, see `https://meta.wikimedia.org/wiki/ORES`.

Installation
============
Use pip to install ORES:

``pip install ores``

Then you can easily run a test server by:

``ores dev_server``

Authors
=======
* [Aaron Halfaker](http://halfaker.info)
* [Yuvi Panda](https://github.com/yuvipanda)
* [Amir Sarabadani](https://github.com/Ladsgroup)
